@@ -40,6 +40,8 @@ if(!isset($_SERVER['PHP_AUTH_PW'])) {
     header("HTTP/1.1 401 Unauthorized");
     print("Access denied. Please send authorisation information");
     debugLog("Access denied: no password sent.");
+	debugLog("end");
+	debugLog("--------");
     return;
 }
 
@@ -54,6 +56,8 @@ if($pos === false){
 }
 $auth_pw = $_SERVER['PHP_AUTH_PW'];
 
+$cmd = $user = $devid = $devtype = "";
+
 // Parse the standard GET parameters
 if(isset($_GET["Cmd"]))
     $cmd = $_GET["Cmd"];
@@ -86,6 +90,25 @@ if(isset($requestheaders["MS-ASProtocolVersion"])) {
     $protocolversion = "1.0";
 }
 
+if (isset($requestheaders["X-Ms-Policykey"])) $requestheaders["X-MS-PolicyKey"] = $requestheaders["X-Ms-Policykey"];
+if (isset($requestheaders["X-MS-PolicyKey"])) {
+    global $policykey;
+    $policykey = $requestheaders["X-MS-PolicyKey"];
+
+} else {
+    global $policykey;
+    $policykey = 0;
+}
+
+//get user agent
+if (isset($requestheaders["User-Agent"])) {
+    global $useragent;
+    $useragent = $requestheaders["User-Agent"];
+} else {
+    global $useragent;
+    $useragent = "unknown";
+}
+
 // Load our backend driver
 $backend_dir = opendir(BASE_PATH . "/backend");
 while($entry = readdir($backend_dir)) {
@@ -106,6 +129,8 @@ if($backend->Logon($auth_user, $auth_domain, $auth_pw) == false) {
     header("WWW-Authenticate: Basic realm=\"ZPush\"");
     print("Access denied. Username or password incorrect.");
     debugLog("Access denied: backend logon failed.");
+    debugLog("end");
+    debugLog("--------");
     return;
 }
 
@@ -116,6 +141,25 @@ if($backend->Setup($user, $devid, $protocolversion) == false) {
     header("WWW-Authenticate: Basic realm=\"ZPush\"");
     print("Access denied or user '$user' unknown.");
     debugLog("Access denied: backend setup failed.");
+    debugLog("end");
+    debugLog("--------");
+    return;
+}
+
+// check policy header 
+if (PROVISIONING === true && $_SERVER["REQUEST_METHOD"] != 'OPTIONS' && $cmd != 'Ping' && $cmd != 'Provision' && 
+    $backend->CheckPolicy($policykey, $devid) != SYNC_PROVISION_STATUS_SUCCESS &&
+    (LOOSE_PROVISIONING === false ||
+    (LOOSE_PROVISIONING === true && isset($requestheaders["X-MS-PolicyKey"])))) {    	
+    	
+    header("HTTP/1.1 449 Retry after sending a PROVISION command");
+    header("MS-Server-ActiveSync: 6.5.7638.1");
+    header("MS-ASProtocolVersions: 1.0,2.0,2.1,2.5");
+    header("MS-ASProtocolCommands: Sync,SendMail,SmartForward,SmartReply,GetAttachment,GetHierarchy,CreateCollection,DeleteCollection,MoveCollection,FolderSync,FolderCreate,FolderDelete,FolderUpdate,MoveItems,GetItemEstimate,MeetingResponse,Provision,ResolveRecipients,ValidateCert,Search,Ping");
+    header("Cache-Control: private");
+    debugLog("POST cmd $cmd denied: Retry after sending a PROVISION command");
+    debugLog("end");
+    debugLog("--------");
     return;
 }
 
@@ -124,7 +168,8 @@ switch($_SERVER["REQUEST_METHOD"]) {
     case 'OPTIONS':
         header("MS-Server-ActiveSync: 6.5.7638.1");
         header("MS-ASProtocolVersions: 1.0,2.0,2.1,2.5");
-        header("MS-ASProtocolCommands: Sync,SendMail,SmartForward,SmartReply,GetAttachment,GetHierarchy,CreateCollection,DeleteCollection,MoveCollection,FolderSync,FolderCreate,FolderDelete,FolderUpdate,MoveItems,GetItemEstimate,MeetingResponse,ResolveRecipipents,ValidateCert,Provision,Search,Ping");
+        header("MS-ASProtocolCommands: Sync,SendMail,SmartForward,SmartReply,GetAttachment,GetHierarchy,CreateCollection,DeleteCollection,MoveCollection,FolderSync,FolderCreate,FolderDelete,FolderUpdate,MoveItems,GetItemEstimate,MeetingResponse,ResolveRecipients,ValidateCert,Provision,Search,Ping");
+        debugLog("Options request");
         break;
     case 'POST':
         header("MS-Server-ActiveSync: 6.5.7638.1");
