@@ -337,6 +337,53 @@ $zpushdtd = array(
                         0x0a => "Folder",
                         0x0b => "ServerEntryId",
                         0x0c => "FolderType",
+                    ), 0xe => array (
+                        0x05 => "Provision",
+                        0x06 => "Policies",
+                        0x07 => "Policy",
+                        0x08 => "PolicyType",
+                        0x09 => "PolicyKey",
+                        0x0A => "Data",
+                        0x0B => "Status",
+                        0x0C => "RemoteWipe",
+                        0x0D => "EASProvisionDoc",
+                        ),
+                    0xf => array(
+                        0x05 => "Search",
+                        0x07 => "Store",
+                        0x08 => "Name",
+                        0x09 => "Query",
+                        0x0A => "Options",
+                        0x0B => "Range",
+                        0x0C => "Status",
+                        0x0D => "Response",
+                        0x0E => "Result",
+                        0x0F => "Properties",
+                        0x10 => "Total",
+                        0x11 => "EqualTo",
+                        0x12 => "Value",
+                        0x13 => "And",
+                        0x14 => "Or",
+                        0x15 => "FreeText",
+                        0x17 => "DeepTraversal",
+                        0x18 => "LongId",
+                        0x19 => "RebuildResults",
+                        0x1A => "LessThan",
+                        0x1B => "GreaterThan",
+                        0x1C => "Schema",
+                        0x1D => "Supported",
+                    ), 0x10 => array(
+                        0x05 => "DisplayName",
+                        0x06 => "Phone",
+                        0x07 => "Office",
+                        0x08 => "Title",
+                        0x09 => "Company",
+                        0x0A => "Alias",
+                        0x0B => "FirstName",
+                        0x0C => "LastName",
+                        0x0D => "HomePhone",
+                        0x0E => "MobilePhone",
+                        0x0F => "EmailAddress",
                     )
               ), "namespaces" => array(
                   1 => "POOMCONTACTS",
@@ -352,6 +399,9 @@ $zpushdtd = array(
                   0xB => "ValidateCerts",
                   0xC => "POOMCONTACTS2",
                   0xD => "Ping",
+                  0xE => "Provision",//
+                  0xF => "Search",//
+                  0x10 => "GAL",
               )
           );
 ?>
\ No newline at end of file
